@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '1.4.3'
+__version__ = '1.4.5'
 
 from .app import Kola
 from .blueprint import Blueprint
+from .utils import safe_call
+from .vals import logger
