@@ -59,7 +59,7 @@ class Connection(object):
     def close(self, exc_info=False):
         """
         直接关闭连接
-        注意: 不要在write完了之后直接调用，会导致write发送不出去
+        注意: 不要在write完了之后直接调用，会导致write发送不出去(这个不太确定，tcp是全双工，理论上关闭了对方也会收到)
         """
         self.stream.close(exc_info)
         self._clear_request_state()
